# QRTransfert
Transfert a single file using QRCodes.

### Requirements
This package requires Python 3

### Installing
To install this CLI tool you can run the below command
```bash
pip3 install qrtransfert
```

### How to use

#### Transfert a single file using QRCodes

```bash
$ qrtransfert encode --help
Usage: qrtransfert encode [OPTIONS]

  Transfert a single file using QRCodes

Options:
  -f FILENAME                     Path of a single file to transfert
                                  [required]
  -c, --qr-color                  Use color QRCode to increase by 3 the data
                                  content in a QRCode
  -t, --terminal                  Display QRCode in terminal
  -qmax, --qr-max-version INTEGER RANGE
                                  Maximun version of the QRCode to generate
                                  
  -qcor, --qr-correction [l|m|q|h]
                                  Define the error correction level for the
                                  QRCode
  -l, --loop-delay FLOAT          Set the loop rotation delay for the QRCodes
                                  in seconds
  -ww, --window-width INTEGER     Width of the windows to display QRCodes
  -wh, --window-height INTEGER    Height of the windows to display QRCodes
  -o, --out-to-file TEXT          Output filename
  --help                          Show this message and exit.
```

#### Decode a video file with QRCodes info a single file

```bash
$ qrtransfert decode --help
Usage: qrtransfert decode [OPTIONS]

  Decode a video file with QRCodes info a single file

Options:
  -f TEXT                         Path of a movie file to decode  [required]
  -ct, --correction-threshold INTEGER RANGE
                                  Image correction threshold
  -fps, --fps-to-decode INTEGER RANGE
                                  Desired fps for decode QRCode
  -d, --debug                     Only display QRCode to adjust the threshold
                                  variable
  --help                          Show this message and exit.
```
